@@ -42,9 +42,12 @@ import (
 	"github.com/helmfile/vals/pkg/providers/oci"
 	"github.com/helmfile/vals/pkg/providers/onepassword"
 	"github.com/helmfile/vals/pkg/providers/onepasswordconnect"
+	"github.com/helmfile/vals/pkg/providers/openbao"
 	"github.com/helmfile/vals/pkg/providers/pulumi"
 	"github.com/helmfile/vals/pkg/providers/s3"
 	"github.com/helmfile/vals/pkg/providers/scaleway"
+	"github.com/helmfile/vals/pkg/providers/secretserver"
+	"github.com/helmfile/vals/pkg/providers/servercore"
 	"github.com/helmfile/vals/pkg/providers/sops"
 	"github.com/helmfile/vals/pkg/providers/ssm"
 	"github.com/helmfile/vals/pkg/providers/tfstate"
@@ -78,6 +81,7 @@ const (
 	defaultCacheSize = 512
 
 	ProviderVault              = "vault"
+	ProviderOpenBao            = "openbao"
 	ProviderS3                 = "s3"
 	ProviderGCS                = "gcs"
 	ProviderGitLab             = "gitlab"
@@ -110,7 +114,9 @@ const (
 	ProviderBitwarden          = "bw"
 	ProviderLockbox            = "yclockbox"
 	ProviderScaleway           = "scw"
+	ProviderSecretserver       = "secretserver"
 	ProviderInfisical          = "infisical"
+	ProviderServercore         = "servercore"
 )
 
 var (
@@ -189,6 +195,9 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 		case ProviderVault:
 			p := vault.New(r.logger, conf)
 			return p, nil
+		case ProviderOpenBao:
+			p := openbao.New(r.logger, conf)
+			return p, nil
 		case ProviderS3:
 			// ref+s3://foo/bar?region=ap-northeast-1#/baz
 			// 1. GetObject for the bucket foo and key bar
@@ -296,9 +305,15 @@ func (r *Runtime) prepare() (*expansion.ExpandRegexMatch, error) {
 		case ProviderScaleway:
 			p := scaleway.New(r.logger, conf)
 			return p, nil
+		case ProviderSecretserver:
+			p := secretserver.New(conf)
+			return p, nil
 		case ProviderInfisical:
 			p := infisical.New(r.logger, conf)
 			return p, nil
+		case ProviderServercore:
+			p := servercore.New(r.logger, conf)
+			return p, nil
 		}
 		return nil, fmt.Errorf("no provider registered for scheme %q", scheme)
 	}
@@ -504,6 +519,7 @@ func cloneMap(m map[string]interface{}) map[string]interface{} {
 
 var KnownValuesTypes = []string{
 	ProviderVault,
+	ProviderOpenBao,
 	ProviderS3,
 	ProviderSSM,
 	ProviderSecretsManager,
