@@ -81,7 +81,7 @@ func TestValues_SSM_String(t *testing.T) {
 				key := "foo"
 				actual := vals[key]
 				if actual != expected {
-					t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+					t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 				}
 			}
 
@@ -92,7 +92,7 @@ func TestValues_SSM_String(t *testing.T) {
 					key := "baz"
 					actual := bar[key]
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of bar: value=%v, type=%T", bar, bar)
@@ -169,7 +169,7 @@ func TestValues_SSM_Map(t *testing.T) {
 					}
 					expected := testValue
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of foo: value=%v, type=%T", foo, foo)
@@ -188,7 +188,7 @@ func TestValues_SSM_Map(t *testing.T) {
 						}
 						expected := testValue
 						if actual != expected {
-							t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+							t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 						}
 					default:
 						t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -263,7 +263,7 @@ func TestValues_SSM_Map_Raw(t *testing.T) {
 					}
 					expected := testValue
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of foo: value=%v, type=%T", foo, foo)
@@ -282,7 +282,7 @@ func TestValues_SSM_Map_Raw(t *testing.T) {
 						}
 						expected := testValue
 						if actual != expected {
-							t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+							t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 						}
 					default:
 						t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -380,7 +380,7 @@ func TestValues_SSM_Map_YAML(t *testing.T) {
 						}
 						expected := testValue
 						if actual != expected {
-							t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+							t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 						}
 					default:
 						t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -489,7 +489,7 @@ func TestValues_SSM_Map_YAML_Root(t *testing.T) {
 					}
 					expected := testValue
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -599,7 +599,7 @@ func TestValues_SSM_Map_Raw_Root(t *testing.T) {
 				}
 				expected := testValue
 				if actual != expected {
-					t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+					t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 				}
 			}
 		})
