@@ -237,7 +237,7 @@ func TestValues_Vault_String(t *testing.T) {
 				key := "foo"
 				actual := vals[key]
 				if actual != expected {
-					t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+					t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 				}
 			}
 
@@ -248,7 +248,7 @@ func TestValues_Vault_String(t *testing.T) {
 					key := "baz"
 					actual := bar[key]
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of bar: value=%v, type=%T", bar, bar)
@@ -411,7 +411,7 @@ func TestValues_Vault_Map(t *testing.T) {
 					}
 					expected := testValue
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of foo: value=%v, type=%T", foo, foo)
@@ -430,7 +430,7 @@ func TestValues_Vault_Map(t *testing.T) {
 						}
 						expected := testValue
 						if actual != expected {
-							t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+							t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 						}
 					default:
 						t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -504,7 +504,7 @@ func TestValues_Vault_Map_Raw(t *testing.T) {
 					}
 					expected := testValue
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of foo: value=%v, type=%T", foo, foo)
@@ -523,7 +523,7 @@ func TestValues_Vault_Map_Raw(t *testing.T) {
 						}
 						expected := testValue
 						if actual != expected {
-							t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+							t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 						}
 					default:
 						t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -639,7 +639,7 @@ func TestValues_Vault_Map_YAML(t *testing.T) {
 						}
 						expected := testValue
 						if actual != expected {
-							t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+							t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 						}
 					default:
 						t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -746,7 +746,7 @@ func TestValues_Vault_Map_YAML_Root(t *testing.T) {
 					}
 					expected := testValue
 					if actual != expected {
-						t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+						t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 					}
 				default:
 					t.Fatalf("unexpected type of baz: value=%v, type=%T", baz, baz)
@@ -853,7 +853,7 @@ func TestValues_Vault_Map_Raw_Root(t *testing.T) {
 				}
 				expected := testValue
 				if actual != expected {
-					t.Errorf("unepected value for key %q: expected=%q, got=%q", key, expected, actual)
+					t.Errorf("unexpected value for key %q: expected=%q, got=%q", key, expected, actual)
 				}
 			}
 		})
